@@ -456,7 +456,9 @@ QVector<Content*> Content::attachments()
 
     auto ct = contentType(false);
     if (ct && ct->isMultipart() && !ct->isSubtype("related") && !ct->isSubtype("alternative")) {
-        Q_FOREACH (Content *child, contents()) {
+        const QVector<Content*> contentsList = contents();
+        result.reserve(contentsList.count());
+        Q_FOREACH (Content *child, contentsList) {
             if (isAttachment(child))
                 result.push_back(child);
             else
@@ -615,6 +617,11 @@ void Content::changeEncoding(Headers::contentEncoding e)
     }
 }
 
+QVector<Headers::Base*> Content::headers() const
+{
+    return d_ptr->headers;
+}
+
 Headers::Base *Content::headerByType(const char *type) const
 {
     Q_ASSERT(type  && *type);
@@ -1033,8 +1040,8 @@ bool ContentPrivate::parseMultipart(Content *q)
     // Create a sub-Content for every part.
     Q_ASSERT(multipartContents.isEmpty());
     body.clear();
-    auto parts = mpp.parts();
-    foreach (const QByteArray &part, mpp.parts()) {
+    const auto parts = mpp.parts();
+    foreach (const QByteArray &part, parts) {
         Content *c = new Content(q);
         c->setContent(part);
         c->setFrozen(frozen);
