@@ -53,10 +53,10 @@ TODO: possible glossary terms:
 #include "kmime_util.h"
 #include "kmime_headers.h"
 
-#include <QtCore/QByteArray>
-#include <QtCore/QVector>
-#include <QtCore/QSharedPointer>
-#include <QtCore/QMetaType>
+#include <QByteArray>
+#include <QVector>
+#include <QSharedPointer>
+#include <QMetaType>
 
 
 namespace KMime
@@ -247,6 +247,12 @@ public:
     */
     void setHead(const QByteArray &head);
 
+    /**
+     * Returns all headers.
+     * @since 5.7
+     */
+    QVector<Headers::Base*> headers() const;
+
     /**
       Returns the first header of type @p type, if it exists.  Otherwise returns 0.
       Note that the returned header may be empty.
