@@ -120,7 +120,7 @@ class UUEncoded : public NonMimeParser
 public:
     UUEncoded(const QByteArray &src, const QByteArray &subject);
 
-    bool parse() Q_DECL_OVERRIDE;
+    bool parse() override;
 
 private:
     QByteArray m_subject;
@@ -135,14 +135,9 @@ class YENCEncoded : public NonMimeParser
 public:
     explicit YENCEncoded(const QByteArray &src);
 
-    bool parse() Q_DECL_OVERRIDE;
-    QVector<QByteArray> binaryParts() const
-    {
-        return m_bins;
-    }
+    bool parse() override;
 
 private:
-    QVector<QByteArray> m_bins;
     static bool yencMeta(QByteArray &src, const QByteArray &name, int *value);
 };
 
